@@ -63,7 +63,7 @@ static int directfd = -1;             /* direct filedes to server, if >= 0 */
 static int verbose;                   /* more tracing */
 static int eflag;                     /* print each updated expression value*/
 static int fflag;                     /* print final expression value */
-static int iflag;                     /* read expresion from stdin */
+static int iflag;                     /* read expression from stdin */
 static int oflag;                     /* print operands as they change */
 static int wflag;                     /* wait for expression to be true */
 static int bflag;                     /* beep when true */
@@ -219,9 +219,9 @@ static void usage()
     fprintf(stderr, "   -o   : print operands as they change\n");
     fprintf(stderr, "   -p p : alternate port, default is %d\n", INDIPORT);
     fprintf(stderr, "   -t t : max secs to wait, 0 is forever, default is %d\n", TIMEOUT);
-    fprintf(stderr, "   -v   : verbose (cummulative)\n");
+    fprintf(stderr, "   -v   : verbose (cumulative)\n");
     fprintf(stderr, "   -w   : wait for expression to evaluate as true\n");
-    fprintf(stderr, "[exp] is an arith expression built from the following operators and functons:\n");
+    fprintf(stderr, "[exp] is an arith expression built from the following operators and functions:\n");
     fprintf(stderr, "     ! + - * / && || > >= == != < <=\n");
     fprintf(stderr, "     pi sin(rad) cos(rad) tan(rad) asin(x) acos(x) atan(x) atan2(y,x) abs(x)\n");
     fprintf(stderr, "     degrad(deg) raddeg(rad) floor(x) log(x) log10(x) exp(x) sqrt(x) pow(x,exp)\n");
